@@ -14,7 +14,7 @@ def load_okex():
     file_pro.change_data_type('trade')
     file_pro.change_timeframe('detail')
     file_pro.change_freq('daily')
-    file_pro.load(total=1)
+    file_pro.load(total=3)
     # file_pro.change_freq('weekly')
     # file_pro.load(total=60)
     # file_pro.change_freq('monthly')
@@ -33,9 +33,9 @@ def load_binance():
     file_pro.change_data_type('trade')
     file_pro.change_timeframe('detail')
     file_pro.change_freq('daily')
-    file_pro.load(total=450)
-    file_pro.change_freq('weekly')
-    file_pro.load(total=60)
+    file_pro.load(total=10)
+    # file_pro.change_freq('weekly')
+    # file_pro.load(total=60)
     # file_pro.change_freq('monthly')
     # file_pro.load(total=12)
 
@@ -47,5 +47,5 @@ def load_binance():
     file_pro.load(total=60)
 
 
-# load_binance()
-load_okex()
+# load_okex()
+load_binance()
