@@ -2,10 +2,12 @@ import csv
 import json
 import logging
 import time
+from datetime import datetime
 
 import ccxt
 import pandas as pd
 from ccxt.base.exchange import Exchange
+from notecoin.base.database import TradeData
 from tqdm import tqdm
 
 logger = logging.getLogger()
@@ -19,20 +21,35 @@ class LoadData:
         self.csv_path = csv_path
         self.unix_start = unix_start
         self.unix_end = unix_end
+        self.cache_data = []
+
+    def load_open(self):
+        pass
 
     def load_all(self, *args, **kwargs):
+        self.load_open()
         self.exchange.load_markets()
         pbr = tqdm(self.exchange.symbols)
         for sym in pbr:
             if ':' not in sym:
                 pbr.set_description(sym)
                 self.load(sym, *args, **kwargs)
+        self.write_data([], False)
+        self.load_close()
+
+    def load_close(self):
+        pass
 
     def load(self, symbol, *args, **kwargs):
         pass
 
-    def write_data(self, data_list):
-        df = pd.DataFrame(data_list)
+    def write_data(self, data_list, cache=True):
+        self.cache_data.extend(data_list)
+        if cache and len(self.cache_data) < 30000:
+            return
+        if len(self.cache_data) == 0:
+            return
+        df = pd.DataFrame(self.cache_data)
         df = df[(df['timestamp'] >= self.unix_start) & (df['timestamp'] <= self.unix_end)]
         self._write(json.loads(df.to_json(orient='records')))
 
@@ -52,9 +69,11 @@ class LoadDataKline(LoadData):
 
     def load(self, symbol, *args, **kwargs):
         unix_temp = self.unix_start
-        while unix_temp < self.unix_end:
+        for _ in range(1000):
+            if unix_temp >= self.unix_end:
+                break
             try:
-                result = self.exchange.fetch_ohlcv(symbol, self.timeframe, unix_temp, limit=1000)
+                result = self.exchange.fetch_ohlcv(symbol, self.timeframe, unix_temp, limit=100)
                 result = self.exchange.sort_by(result, 0)
                 if len(result) == 0:
                     break
@@ -62,7 +81,7 @@ class LoadDataKline(LoadData):
                 df = pd.DataFrame(result, columns=['timestamp', 'open', 'close', 'low', 'high', 'vol'])
                 df['symbol'] = symbol
                 self.write_data(json.loads(df.to_json(orient='records')))
-                time.sleep(int(self.exchange.rateLimit / 1000))
+                #time.sleep(int(self.exchange.rateLimit / 1000))
             except Exception as e:
                 print(type(e).__name__, str(e))
                 self.exchange.sleep(10000)
@@ -71,17 +90,24 @@ class LoadDataKline(LoadData):
 class LoadTradeKline(LoadData):
     def __init__(self, *args, **kwargs):
         super(LoadTradeKline, self).__init__(*args, **kwargs)
-        self.csv_writer = csv.DictWriter(open(self.csv_path, mode="w"), delimiter=",",
-                                         fieldnames=["symbol", "id", "timestamp", "type", "side", "price", "amount"])
+        # self.csv_writer = csv.DictWriter(open(self.csv_path, mode="w"), delimiter=",",
+        #                                  fieldnames=["symbol", "id", "timestamp", "type", "side", "price", "amount"])
+        self.table = TradeData(prefix=self.exchange.name,
+                               suffix=datetime.utcfromtimestamp(self.unix_start / 1000).strftime('%Y%m%d'))
+
+    def load_close(self):
+        self.table.to_csv_all(file_path=self.csv_path)
 
     def _write(self, data_list):
-        self.csv_writer.writerows(data_list)
+        self.table.insert(values=data_list)
+        # self.csv_writer.writerows(data_list)
 
     def load(self, symbol, *args, **kwargs):
         unix_temp = self.unix_start
         previous_trade_id = None
-
-        while unix_temp < self.unix_end:
+        for _ in range(1000):
+            if unix_temp >= self.unix_end:
+                break
             try:
                 trades = self.exchange.fetch_trades(symbol, unix_temp, limit=1000)
                 if len(trades) == 0:
@@ -105,7 +131,7 @@ class LoadTradeKline(LoadData):
                 } for trade in trades]
 
                 self.write_data(result)
-                time.sleep(int(self.exchange.rateLimit / 1000))
+                #time.sleep(int(self.exchange.rateLimit / 1000))
             except ccxt.NetworkError as e:
                 print(type(e).__name__, str(e))
                 self.exchange.sleep(10000)
